@@ -1,7 +1,7 @@
-//! The drawing surface and piston window used to display the set of points via the render and update window events
+//! The drawing surface and piston window used to display the set of points.
 use crate::{constants, decluster::decluster, point::Point};
 use graphics::{clear, rectangle};
-use piston::{RenderEvent, UpdateEvent};
+use piston::{RenderArgs, RenderEvent, UpdateEvent};
 use piston_window::{PistonWindow, WindowSettings};
 
 pub struct Canvas {
@@ -20,13 +20,6 @@ impl Canvas {
 
     * `point_count` - the number of points in the set
     * `min_distance` - if a pair of points are closer than the `min_distance`, then one of the points will be removed and replaced with a fresh random [point](crate::point::Point)
-
-    # Examples
-
-    ```
-    use decluster::Canvas;
-    let canvas = Canvas::new(500, 60.0);
-    ```
     */
     pub fn new(point_count: usize, min_distance: f64) -> Self {
         let window: PistonWindow = WindowSettings::new("decluster", [0, 0])
@@ -44,6 +37,9 @@ impl Canvas {
         }
     }
 
+    /**
+    Begins the decluster loop by listening for render and update window events.
+    */
     pub fn show(&mut self) {
         while let Some(e) = self.window.next() {
             if let Some(args) = e.render_args() {
@@ -55,8 +51,11 @@ impl Canvas {
             }
         }
     }
-
-    fn render(&mut self, e: &piston::Event, args: piston::RenderArgs) {
+    /**
+    Lazy initialises the the set of points to random locations. This needs to be delayed until the first render so the full-size window dimensions can be
+    can be used to constrain the random locations. This window size only become available when the window is first rendered.
+    */
+    fn render(&mut self, e: &piston::Event, args: RenderArgs) {
         if let None = self.points {
             self.points = Some(Point::rnd_vec(args.window_size, self.point_count));
             self.window_size = args.window_size;
@@ -75,7 +74,10 @@ impl Canvas {
             }
         });
     }
-
+    /**
+    Declusters the current set of points then refills the set with new randomised points. This amounts to a random search for a viable set, that is a set of points
+    where each individual point is seprated by at least the minimum distance.
+    */
     fn update(&mut self) {
         if let Some(points) = self.points.as_mut() {
             let len = points.len();
